package com.fs.wx.sop.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.wx.sop.domain.WxSop;
import com.fs.common.core.domain.R;

/**
 * 个微SOPService接口
 * 
 * @author 吴树波
 * @date 2026-02-24
 */
public interface IWxSopService extends IService<WxSop>{
    /**
     * 查询个微SOP
     * 
     * @param id 个微SOP主键
     * @return 个微SOP
     */
    WxSop selectWxSopById(Long id);

    /**
     * 查询个微SOP详情（含执行账号 companyUserIds）
     * 
     * @param id 个微SOP主键
     * @return 个微SOP
     */
    WxSop selectWxSopDetailById(Long id);

    /**
     * 查询个微SOP列表
     * 
     * @param wxSop 个微SOP
     * @return 个微SOP集合
     */
    List<WxSop> selectWxSopList(WxSop wxSop);

    /**
     * 新增个微SOP
     * 
     * @param wxSop 个微SOP
     * @return 结果
     */
    int insertWxSop(WxSop wxSop);

    /**
     * 修改个微SOP
     * 
     * @param wxSop 个微SOP
     * @return 结果
     */
    int updateWxSop(WxSop wxSop);

    /**
     * 批量删除个微SOP
     * 
     * @param ids 需要删除的个微SOP主键集合
     * @return 结果
     */
    int deleteWxSopByIds(Long[] ids);

    /**
     * 删除个微SOP信息
     * 
     * @param id 个微SOP主键
     * @return 结果
     */
    int deleteWxSopById(Long id);
    
    /**
     * 批量执行个微SOP
     * 
     * @param ids 个微SOP主键数组
     * @return 结果
     */
    R updateStatusWxSopByIds(Long[] ids);
}
